AutoStopCriteria class

Define a criteria under which the positioning will be automatically stopped.

Constructors

AutoStopCriteria({Duration? consecutiveOutOfBuildingTimeout})

Properties

consecutiveOutOfBuildingTimeout → Duration?
Time duration receiving consecutive StatusNames.userNotInBuilding after which positioning will be automatically stopped.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited