Geofence class

Represents a geographic region in a Building. Can be monitored to check if an user enter or exits the polygon and to get analytics.

Inheritance

Constructors

Geofence({required String identifier, required String name, required String buildingId, required String floorId, required List<Point> polygonPoints, required String createdAt, required String updatedAt, required Map<String, dynamic> customFields})

Properties

buildingId → String
final
createdAt → String
final
customFields → Map<String, dynamic>
final
floorId → String
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
finalinherited
name → String
finalinherited
polygonPoints → List<Point>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited