onDirectionsRequestInterceptor method

  1. @Deprecated('Routes are now calculated and managed by the MapView. ' 'This method is kept for backward compatibility and has no effect.')
void onDirectionsRequestInterceptor(
  1. OnDirectionsRequestInterceptor callback
)

Implementation

@Deprecated('Routes are now calculated and managed by the MapView. '
    'This method is kept for backward compatibility and has no effect.')
void onDirectionsRequestInterceptor(
    OnDirectionsRequestInterceptor callback) {}