onNavigationRequestInterceptor method

  1. @Deprecated('Navigation is now calculated and managed by the MapView. ' 'This method is kept for backward compatibility and has no effect.')
void onNavigationRequestInterceptor(
  1. OnNavigationRequestInterceptor callback
)

Implementation

@Deprecated('Navigation is now calculated and managed by the MapView. '
    'This method is kept for backward compatibility and has no effect.')
void onNavigationRequestInterceptor(
    OnNavigationRequestInterceptor callback) {}