OnDirectionsRequestInterceptor typedef

  1. @Deprecated('Direction requests are no longer forwarded from the MapView to the ' 'native SDK. This type is kept for backward compatibility and is no ' 'longer used internally.')
OnDirectionsRequestInterceptor = void Function(DirectionsRequest directionsRequest)

Implementation

@Deprecated(
    'Direction requests are no longer forwarded from the MapView to the '
    'native SDK. This type is kept for backward compatibility and is no '
    'longer used internally.')
typedef OnDirectionsRequestInterceptor = void Function(
    DirectionsRequest directionsRequest);