OnNavigationRequestInterceptor typedef

  1. @Deprecated('Navigation requests are no longer forwarded from the MapView to the ' 'native SDK. This type is kept for backward compatibility and is no ' 'longer used internally.')
OnNavigationRequestInterceptor = void Function(NavigationRequest navigationRequest)

Implementation

@Deprecated(
    'Navigation requests are no longer forwarded from the MapView to the '
    'native SDK. This type is kept for backward compatibility and is no '
    'longer used internally.')
typedef OnNavigationRequestInterceptor = void Function(
    NavigationRequest navigationRequest);