OnSpeakAloudTextResult class

This class represents the object that contains the message passed from the viewer to the application. This message represents the requirement to read aloud a text with some parameters like language, volume, etc

Constructors

OnSpeakAloudTextResult({required String text, String? lang, double? volume, double? pitch, double? rate})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lang → String?
A String that represents the language code, i.e. es-ES
final
pitch → double?
A Double that represents the speech pitch from 0.0 to 1.0
final
rate → double?
A Double that represents the speech rate from 0.0 to 1.0
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
A String that will be read aloud using TTS
final
volume → double?
A Double that represents the volume from 0.0 to 1.0
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited