createDirectionsMessage function
- @Deprecated('The plugin no longer handles direction requests from the MapView. ' 'This function is kept for backward compatibility and is no longer ' 'called internally.')
DirectionsMessage
createDirectionsMessage(
- dynamic arguments
)
Implementation
@Deprecated('The plugin no longer handles direction requests from the MapView. '
'This function is kept for backward compatibility and is no longer '
'called internally.')
DirectionsMessage createDirectionsMessage(arguments) => DirectionsMessage(
buildingIdentifier: arguments["buildingIdentifier"],
originIdentifier: stringFromArgsOrEmptyId(arguments, "originIdentifier"),
originCategory: arguments["originCategory"],
destinationIdentifier:
stringFromArgsOrEmptyId(arguments, "destinationIdentifier"),
destinationCategory: arguments["destinationCategory"],
identifier: (arguments["identifier"] ?? "").toString(),
accessibilityMode:
createAccessibilityMode(arguments["directionsRequest"]),
);